@@ -482,41 +482,47 @@ HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, Hardwa
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,
                                                               exclude=['updated_at', 'created_at'])
 
+from django.utils.safestring import mark_safe
 
 class DataTransformerForm(BaseInlineFormSet):
 
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
-        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self,
                                                              fk_name='data_transformer_parent',
                                                              extra=1, exclude=['updated_at', 'created_at'],
-                                                             form=self.__class__)
+                                                             form=self.DataTransform)
         form.nested_data_transformer_form = dataTransformerInlineFormset(
-            instance=self.instance,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
+            initial=form.instance.getChildren(),
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
             extra=1)
 
         form.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=self.instance,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
             extra=1)
 
         form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=self.instance,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
             extra=1)
 
         form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=self.instance,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
             extra=1)
 
+    def as_p(self):
+        super(DataTransformerForm, self).as_p()
+        forms = ' '.join(' '.join([form.as_p(),form.nested_data_transformer_form,form.nested_constants_form,form.nested_hardware_outputs_form,form.nested_hardware_stats_form]) for form in self)
+        return mark_safe(str(self.management_form) + '\n' + forms)
 
-class DataTransform(forms.Form):
+
+class DataTransform(forms.ModelForm):
     id = forms.CharField(required=False,
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}))
     accessory = forms.CharField(required=False,
