@@ -390,7 +390,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
         datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,form=DataTransform,formset=DataTransformerForm,
-                                                   fk_name='data_transformer_parent',
+                                                   fk_name='parent',
                                                    extra=1, exclude=['updated_at', 'created_at'])
 
         if accessory.has_data_transformer:
